/* Implementierung der bilinear transformierten RC-Tiefpass Uebertragungsfunktion gemaess
   Aufgabe Kurs DSP vom 18.11.2000

  Autor: Gerhard Krucker
         Zaunackerstrasse 39
	     3113 Rubigen
   Datum: 20.11.2000
   Sprache: Tasking C56 C-Compiler 2.0r8
*/

#include <reg56002.h>
#include <limits.h>
#include "cs4215.h"
#include "codecConst.h"			// Konstanten fuer Coedec CS4215 Initialisierung

#define TONE_OUTPUT     HEADPHONE_EN+LINEOUT_EN+(4*LEFT_ATTN)+(4*RIGHT_ATTN)     // Lautstaerkefaktoren
#define TONE_INPUT      MIC_IN_SELECT+(15*MONITOR_ATTN)


//----------------------------------------------------------------------------------------------------
// Die nachfolgend definierten Datenpuffer sind Sende- und Empfangsspeicher fuer die
// Daten vom Codec, die ueber die RX-TX ISR uebertragen werden.
// Das Modul adaCS4215 setzt voraus, dass rxData, txData und die Zeiger rxPtr, txPtr genau so
// definiert werden, da sie dort extern referenziert werden.
//----------------------------------------------------------------------------------------------------
_X _near _circ CS4215DATA rxData;	     // SSI RX Datenpuffer
_X _near _circ CS4215DATA txData;	     // SSI TX Datenpuffer
_X _circ _fract *rxPtr=rxData.b;  	     // Pufferzeiger RX Ringpuffer
_X _circ _fract *txPtr=txData.b;             // Pufferzeiger TX Ringpuffer


_Y _fract y;                                 // Ausgangswerte zum Codec
_X _fract x;				      // Eingangswerte vom Codec

/* Funktionsprotortypen */
void codecInit(int, int, int, int);       // CS4215 Codec und zugehoerige Interruptroutinen initialisieren


/* Tiefpassfilter erster Ordnung (kritische Daempfung) in direkter Form, d.h. mit zwei Speicherzellen realisiert,
   wie im Unterricht gezeigt:

   			-----
   X(n)       0.2534 + |     |                     y(n)
   ------------------->| Sum |------------------------>
       |               |     |  	   |
    ------		--+--	         ------
   |	  |		  |	        |      |
   | z^-1 |	  	  |	        | z^-1 |
   |	  |	  	  |	        |      |
    ------	  	  |	         ------
       |      0.2534   +  |  - (-0.49314)  |
        ----------------->+<---------------

   Designdaten:
      fc=1kHz, fs=9.6kHz
      wc=6517.5 rad/s (mit Prewarping)


   Die Datenueber- und -rueckgabe erfolgt mittels Seiteneffekt ueber die globalen Variablen x und y.
*/


void filterRC(void)
{ static _fract xz1,yz1;   // Zeitverzoegerte Signale um eine Periode fuer x und y

  y=0.2534 * x + 0.2534 * xz1 + 0.49314 * yz1;	// G(z)
  xz1= x;                                       // x -> z^-1
  yz1= y;					// y -> z^-1
}



int main(void)

/* Hauptprogramm, Daten von Codec holen und je nach Brueckenstellung gefiltert oder direkt ausgeben.
*/

{  PCTL.I=0x261009;         // PLL des DSP setzen
   PBC = 0;                 // Port B als Ein/Ausgaenge konfigurieren
   PBDDR = 0x0100;          // PB0..PB7,PB9..PB14 als Eingang definieren. PB8 als Ausgang.
   PBD=0x0;                 // PB8 auf 0. PB8 dient als GND fuer Bruecke zu PB14(HACK)
   //
   // Codec Initialisieren:9.6kHz Sample Rate, Stereo, mit HP Filter, 16 Bit Datenwerte...
   //
   codecInit(NO_PREAMP | HI_PASS_FILT | SAMP_RATE_9 | STEREO+DATA_16 ,   // CTRL_WD_12
	    IMMED_3STATE |XTAL2_SELECT | BITS_64 | CODEC_MASTER,         // CTRL_WD_34
	    0x000000,						         // CTRL_WD_56
	    0x000000						         // CTRL_WD_78
	    );


  while(1)
  { while( SSISR.B.TFS);	 	     //Warten auf frame sync Transition
    while(!SSISR.B.TFS)
    x =  rxData.d.i.audio_left;

    if (PBD & 0x4000)                // PB14-PB8 keine Bruecke?
        y = x;                       // Audio direkt passieren lassen
      else
        filterRC();                  // Audio gefiltert ausgeben

    txData.d.i.audio_left=y;
    txData.d.i.audio_right=(_fract)0.0;                // Rechter Kanal nichts
    txData.d.i.output_setting=TONE_OUTPUT;
    txData.d.i.input_setting=TONE_INPUT;
  }
 return 0;
}
