/* Header File CodecConst.h

   Konstanten zur Initialisierung des CS4215 Codec vom Cristal Semicoductor.

   Referenzen: - CS4215 Datenblatt #DFF76F2, Sept. 93, Crystal Semicoductor Corporation.
	       - Motorola EVM22 Kit Demo Beispiel File ADA-INIT.ASM
   Autor: Gerhard Krucker
          Zaunackerstrasse 9
	  CH-3113 Rubigen
   Sprache: Tasking C56 V2.0r8
   Datum: 16.10.2000
*/

/****************************************************************************
  Konstanten zum Zusammenstellen der Mode- und Kontrollworte fuer die
  CONTROL TIME SLOTS
 ****************************************************************************/
#define NO_PREAMP     0x100000 			// 0 == 20 dB pre-amp eingeschaltet 
#define LO_OUT_DRV    0x080000 			// 0 == 2.8 Vp-p line (1V rms)
                                		// 0 == 4.0 Vp-p Kopfhoerer
                               			// 1 == Line und Kopfhoerer 2.0Vp-p
#define HI_PASS_FILT   0x008000 		// 0 == HPF ausgeschaltet
#define SAMP_RATE_9    0x003800 		//  9.6 kHz Sample Rate
#define SAMP_RATE_48   0x003000 		// 48   kHz Sample Rate
#define SAMP_RATE_32   0x001800 		// 32   kHz Sample Rate
#define SAMP_RATE_27   0x001000 		// 27.4 kHz Sample Rate
#define SAMP_RATE_16   0x000800 		// 16   kHz Sample Rate
#define SAMP_RATE_8    0x000000 		// 8   kHz Sample Rate
#define STEREO         0x000400 		// 1 == Stereo, 0 == Mono
#define DATA_8LIN      0x200300 		// 8-bit unsigned linear
#define DATA_8A        0x200200 		// 8-bit A-law
#define DATA_8U        0x200100 		// 8-bit u-law
#define DATA_16        0x200000 		// 16-bit 2er Komplement linear
#define IMMED_3STATE   0x800000 		// 1=SCLK & FS 3-state immediate
#define XTAL2_SELECT   0x200000 		// BENOETIGT, weil dies die einzige Clock-
                                		//  quelle auf dem Board ist.
#define BITS_64        0x000000 		// 64 Bits per Frame
#define BITS_128       0x040000 		// 128 Bits per Frame
#define BITS_256       0x080000 		// 256 Bits per Frame
#define CODEC_MASTER   0x020000 		// 1 == Codec erzeugt SCLK & FS
                                		// 0 == Codec erhaelt  SCLK & FS
#define CODEC_TX_OFF   0x010000 		// 0 == Codec TX zum DSP freigeben
                                		// 1 == Codec Ausgang sperren (Hi-Z) 

/****************************************************************************
  Defined Constants used to construct data for the DATA TIME SLOTS  (5-8)
 ***************************************************************************/
#define HEADPHONE_EN    0x800000 		// 1 == Kopfhoerausgang freigeben, 0 == gesperrt        
#define LINEOUT_EN      0x400000 		// 1 == Line- Ausgang freigeben,   0 == gesperrt
#define LEFT_ATTN       0x010000 		// 63 Schritte * 1.5 dB = -94.5 dB
#define SPEAKER_EN      0x004000 		// 1 == Lautsprecherasugang freigeben, 0 == gesperrt
#define RIGHT_ATTN      0x000100 		// 63 Schritte * 1.5 dB = -94.5 dB
#define MIC_IN_SELECT   0x100000 		// 1 == A/D Eingang von der MIC-Buchse Bemerkung: Das DSP56002EVM 
                                		//    benutzt nur diese Eingaenge. Die Line-Eingaenge sind nicht benutzt. 
#define LEFT_GAIN       0x010000 		// 15 Schritte * 1.5 dB =  22.5 dB
#define MONITOR_ATTN    0x001000 		// 15 Schritte * 6.0 dB =  90.0 dB (mute)
#define RIGHT_GAIN      0x000100 		// 15 Schritte * 1.5 dB =  22.5 dB

//----------------------------------------------------------------------------
// Zusammengestzte Kontrollworte zur Initialisierung (Set Up) des Codec
//----------------------------------------------------------------------------
#define CTRL_WD_12      NO_PREAMP | HI_PASS_FILT | SAMP_RATE_27 | STEREO+DATA_16   
#define CTRL_WD_34      IMMED_3STATE |XTAL2_SELECT | BITS_64 | CODEC_MASTER
#define CTRL_WD_56      0x000000
#define CTRL_WD_78      0x000000

//----------------------------------------------------------------------------
//  Zusammengestzte Modeworte fuer die Datenuebertagung
//----------------------------------------------------------------------------
#define OUTPUT_SET      HEADPHONE_EN+LINEOUT_EN+(LEFT_ATTN*4)
#define INPUT_SET       MIC_IN_SELECT+(15*MONITOR_ATTN)+(RIGHT_ATTN*4)

